@@ -4,8 +4,6 @@
 # --> Configuration class handles Cognicept configuration
 
 from dotenv import dotenv_values
-from dotenv import load_dotenv
-from dotenv import find_dotenv
 from pathlib import Path
 from Crypto.PublicKey import RSA
 import subprocess
@@ -29,12 +27,12 @@ class Configuration:
         object.config_path = os.path.expanduser(path)
         object.env_path = object.config_path + "runtime.env"
         file = Path(object.env_path)
-
+        
         if ((not file.exists()) or (file.is_dir())):
             print("Configuration file `" + object.env_path + "` does not exist.")
             return False
-
-        object.config = dotenv_values(file) if sys.version_info.minor > 5 else dotenv_values(dotenv_path=find_dotenv(), verbose=True)
+        
+        object.config = dotenv_values(file)
 
         if(len(object.config) == 0):
             print("Configuration file `" + object.env_path + "` is empty or could not be parsed.")
@@ -46,7 +44,7 @@ class Configuration:
     def configure(object, args):
         if(not object._config_loaded):
             return
-
+        
         if (not os.access(object.env_path, os.W_OK)):
             print("Error: You don't have writing permissions for `" + object.env_path + "`. Run as `sudo` or change file permissions.")
             return
@@ -66,7 +64,7 @@ class Configuration:
                 if matches is None:
                     print("Error: Key can be uppercase letters, digits, and the '_'. Try again.")
                     new_key = ""
-
+            
             new_value = ""
             while(new_value == ""):
                 new_value = input("Value: ")
@@ -79,7 +77,8 @@ class Configuration:
 
             object.config[new_key] = new_value
         elif(args.ssh):
-            object.configure_ssh()
+            if object.configure_ssh():                
+                print ('SSH config done. To apply changes restart agents using `cognicept restart`.')
         else:
             for key, value in object.config.items():
                 new_value = input(key + "[" + value + "]:")
@@ -95,24 +94,24 @@ class Configuration:
                     file.write(key + '=' + value + '\n')
         except IOError:
             print("Could not write into `" + object.env_path + "`. Please check write permission or run with `sudo`.")
-
+    
     def cognicept_login(object):
         print("Please enter your Cognicept credentials.")
-
+        
         username = input("Username: ")
-        try:
-            password = getpass.getpass()
-        except Exception as error:
+        try: 
+            password = getpass.getpass() 
+        except Exception as error: 
             print('Error when reading password.')
             return False
-
+        
         try:
             resp = requests.post(object.get_cognicept_api_uri() + 'user/login', json = {"username": username, "password": password}, timeout = 5)
             if resp.status_code != 200:
                 print('Login error: wrong credentials.')
                 return False
-
-            object.config["COGNICEPT_JWT"] = resp.json()["access_token"]
+            
+            object.config["COGNICEPT_JWT"] = resp.json()["access_token"]            
         except requests.exceptions.Timeout:
             print("Cognicept REST API error: time out.")
             return
@@ -124,7 +123,7 @@ class Configuration:
             raise SystemExit()
         object.save_config()
 
-
+        
 
         return True
 
@@ -159,7 +158,7 @@ class Configuration:
             return None
 
     def configure_ssh(object):
-        print('SSH is used to access the host machine from the isolated docker environment of `remote_intervention_agent`.')
+        print('SSH is used to access the host machine from the isolated docker environment of Cognicept agent.')
 
         enable_ssh = None
         while(enable_ssh == None):
@@ -188,49 +187,60 @@ class Configuration:
 
         if(not enable_ssh_key):
             object.config["COG_ENABLE_SSH_KEY_AUTH"] = "False"
-            object.config["COG_ENABLE_AUTOMATIC_SSH"] = "False"
-            object.save_config()
-            return True
         else:
             object.config["COG_ENABLE_SSH_KEY_AUTH"] = "True"
 
-        cognicet_ssh_directory = object.config_path + "ssh/"
-        try:
-            if not os.path.exists(cognicet_ssh_directory):
-                os.makedirs(cognicet_ssh_directory)
-        except:
-            print("Failed. Don't have privileges to create files/directories within the ssh directory.")
-            return False
-        
-        # generate the keys
-        ssh_key = RSA.generate(2048)
-        private_key_path = cognicet_ssh_directory + "id_rsa"
-        public_key_path = cognicet_ssh_directory + "id_rsa.pub"
-        config_file_path = cognicet_ssh_directory + "config"
-        with open(private_key_path, 'wb') as content_file:
-            os.chmod(private_key_path, 0o600)
-            content_file.write(ssh_key.exportKey('PEM'))
-        pub_key = ssh_key.publickey().exportKey('OpenSSH')
-        with open(public_key_path, 'wb') as content_file:
-            content_file.write(pub_key)
-        # add new line at the end of the file
-        with open(public_key_path, 'a') as content_file:
-            content_file.write("\n")
+        # generate the ssh key and write them in the file
+        if object.config["COG_ENABLE_SSH_KEY_AUTH"] == "True":
+            cognicet_ssh_directory = object.config_path + "ssh/"
+            try:
+                if not os.path.exists(cognicet_ssh_directory):
+                    os.makedirs(cognicet_ssh_directory)
+            except:
+                print("Failed. Don't have privileges to create files/directories within the ssh directory.")
+                return False
+            
+            # generate the keys
+            ssh_key = RSA.generate(2048)
+            private_key_path = cognicet_ssh_directory + "id_rsa"
+            public_key_path = cognicet_ssh_directory + "id_rsa.pub"
+            config_file_path = cognicet_ssh_directory + "config"
+            with open(private_key_path, 'wb') as content_file:
+                os.chmod(private_key_path, 0o600)
+                content_file.write(ssh_key.exportKey('PEM'))
+            pub_key = ssh_key.publickey().exportKey('OpenSSH')
+            with open(public_key_path, 'wb') as content_file:
+                content_file.write(pub_key)
+            # add new line at the end of the file
+            with open(public_key_path, 'a') as content_file:
+                content_file.write("\n")
 
         default_user = getpass.getuser()
+        user_exists = False
+        ssh_directory_path = ""
 
-        user_name = input("Name of the user to access ssh(if empty, defaults to `" + default_user + "`): ")
-        if(user_name == ""):
-            user_name = default_user
-        object.config["COG_SSH_DEFAULT_USER"] = user_name
+        # retrieve the user name
+        while not user_exists:
+            user_name = input("Name of the user to access ssh(if empty, defaults to `" + default_user + "`): ")
+            if(user_name == ""):
+                user_name = default_user
+            object.config["COG_SSH_DEFAULT_USER"] = user_name
 
-        authorized_keys_path = "/home/" + user_name + "/.ssh/authorized_keys"
-        try:
-            print('Root access is needed to modify `' + authorized_keys_path + '` and you will be prompted for password.')
-            proc = subprocess.call(['sudo', 'sh', '-c', 'cat ' + public_key_path + ' >> ' + authorized_keys_path])
-        except:
-            print("Failed! Don't have access to " + authorized_keys_path)
-            return
+            ssh_directory_path = "/home/" + user_name + "/.ssh/"
+            if os.path.exists(ssh_directory_path):
+                user_exists = True
+            else:
+                print("User " + user_name + " doesn't seem to exist or openssh server is not installed.")
+
+        # copy the keys to authorized_keys file if automatic authentication was enabled
+        if object.config["COG_ENABLE_SSH_KEY_AUTH"] == "True":
+            authorized_keys_path = ssh_directory_path + "authorized_keys"
+            try:
+                print('Root access is needed to modify `' + authorized_keys_path + '` and you will be prompted for password.')
+                proc = subprocess.call(['sudo', 'sh', '-c', 'cat ' + public_key_path + ' >> ' + authorized_keys_path])
+            except:
+                print("Failed! Don't have access to " + authorized_keys_path)
+                return
 
 
         enable_automatic_ssh = None
@@ -243,5 +253,10 @@ class Configuration:
             object.config["COG_ENABLE_AUTOMATIC_SSH"] = "True"
         
         object.save_config()
-        print ('SSH config done. To apply changes restart agents using `cognicept restart`.')
-        return True
\ No newline at end of file
+        return True
+
+    def is_ssh_enabled(object):
+        if(not "COG_ENABLE_SSH_KEY_AUTH" in object.config):
+            return False
+        
+        return object.config["COG_ENABLE_SSH_KEY_AUTH"]
\ No newline at end of file
